==> qgis_0.6.0.orig.tar.gz: qgis-0.6.0/src/qgsrasterlayerpropertiesbase.ui.h <==



/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/






void QgsRasterLayerPropertiesBase::sliderMaxRed_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMinRed_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMaxBlue_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMinBlue_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMaxGreen_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMinGreen_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMaxGray_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMinGray_valueChanged( int )
{

}



void QgsRasterLayerPropertiesBase::sliderTransparency_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::rbtnSingleBand_toggled( bool )
{

}


void QgsRasterLayerPropertiesBase::rbtnThreeBand_toggled( bool )
{

}


void QgsRasterLayerPropertiesBase::apply()
{

}


void QgsRasterLayerPropertiesBase::sliderTransparency_sliderMoved( int )
{

}


void QgsRasterLayerPropertiesBase::buttonBuildPyramids_clicked()
{

}

==> qgis_0.7.4.orig.tar.gz: qgis-0.7.4/src/qgsrasterlayerpropertiesbase.ui.h <==



/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/






void QgsRasterLayerPropertiesBase::sliderMaxRed_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMinRed_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMaxBlue_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMinBlue_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMaxGreen_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMinGreen_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMaxGray_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::sliderMinGray_valueChanged( int )
{

}



void QgsRasterLayerPropertiesBase::sliderTransparency_valueChanged( int )
{

}


void QgsRasterLayerPropertiesBase::rbtnSingleBand_toggled( bool )
{

}


void QgsRasterLayerPropertiesBase::rbtnThreeBand_toggled( bool )
{

}


void QgsRasterLayerPropertiesBase::apply()
{

}


void QgsRasterLayerPropertiesBase::sliderTransparency_sliderMoved( int )
{

}


void QgsRasterLayerPropertiesBase::buttonBuildPyramids_clicked()
{

}


void QgsRasterLayerPropertiesBase::pbnHistRefresh_clicked()
{

}


void QgsRasterLayerPropertiesBase::pbnChangeSpatialRefSys_clicked()
{

}
